<div align="center">
[![Platform](https://img.shields.io/badge/platform-linux--64%20%7C%20win--32%20%7C%20osx--64%20%7C%20win--64-lightgrey)]()
(https://github.com/zasexton/svcco)
</div>
Synthetic Vascular Optimization (SVO) an open-source API for automated vascular generation and multi-fidelity hemodynamic simulation written in Python. Often small-caliber vessels are difficult or infeasible to obtain from experimental data sources despite playing important roles in blood flow regulation and cell microenvironments. SVCCO aims to provide tissue engineers and computational hemodynamic scientists with de novo vasculature that can easily be applied in biomanufacturing applications or computational fluid dynamic (CFD) analysis.
